:orphan:

`plasmapy.analysis.swept_langmuir.floating_potential`
=====================================================

.. currentmodule:: plasmapy.analysis.swept_langmuir.floating_potential

.. automodapi:: plasmapy.analysis.swept_langmuir.floating_potential
